<?php
namespace Fiscal\Logic\ImportaTipoItem;

use Geral\Entities\TipoItemProd;
use Geral\Util\DateUtil;
use Geral\Util\Ambiente;
use Indeterminado\Entities\RelacProdItGen;
use Setforms2\Shared\Registry;

class TipoItem
{
    public static function replicaItemProd($nrorg, $cdLivroOrig, $cdLivroDest){
        
        /*Validação para verificar se o cadastro de tipo de item do livro de origem está vazio.*/
        self::validaTipoItemLivroVazio($nrorg, $cdLivroOrig);

        /*Valida se existe algum cadastro de Produto por Tp. Item/Gênero pois assim os tipos de itens atuais não podem ser substituídos.*/
        $proditgen = RelacProdItGen::findByNrorgAndCdlivromag($nrorg, $cdLivroDest);
        if ($proditgen == null) {
            $connection = \Setforms2\Shared\Registry::getEntityManagerConnection();
            $connection->beginTransaction();

            try{
                self::replicaRegistrosItem($nrorg, $cdLivroOrig, $cdLivroDest);
                $connection->commit();
            } catch (\Exception $e){
                $connection->rollback();
                throw $e;
            }  

        } else {
            throw new \Exception ("Operação Bloqueada! Os cadastros não podem ser substituídos pois estão sendo usados na aba Produto por Tipo de Item/Gênero.");
        }
    }

    public static function validaTipoItemLivroVazio($nrorg, $cdLivroMag)
    {
        /*A função valida se existe algum tipo de item cadastrado para o livro informado como parãmetro.*/
        $tipoitem = TipoItemProd::findByNrorgAndCdlivromag($nrorg, $cdLivroMag);

        if ($tipoitem == null) {
            throw new \Exception ("Operação Bloqueada! Não existe tipo de item cadastrado para o livro magnético de origem informado.");
        }
    }

    public static function replicaRegistrosItem($nrorg, $cdLivroOrig, $cdLivroDest) {
        
        /*A função replica os tipos de item entre os livros conforme os parâmetros informados, de forma que,
          são excluídos todos os tipos de item do livro de destino e então são inseridos todos os itens do livro
          de origem para o livro de destino.*/

        $dataAtual = DateUtil::getDataAtual();
        $cdoperador = Ambiente::getCdOperador();

        try {

            /*São apagados os cadastros de Tipo de Item do livro de destino para serem incluídos os novos.*/
            $repositorioTipoItemProd = TipoItemProd::getRepository();
            $repositorioTipoItemProd->deleteByCdlivromagAndNrorg($cdLivroDest, $nrorg);
            Registry::getEntityManager()->flush();

            /*São buscados todos os tipos de item do livro de origem e para cada um são criados novos itens com o código do livro de destino.*/
            $itensprod = TipoItemProd::findByNrorgAndCdlivromag($nrorg, $cdLivroOrig);

            foreach ($itensprod as $itemprod) {
                $newitemprod = new TipoItemProd();
                $newitemprod->setCdlivromag($cdLivroDest);
                $newitemprod->setCdtpitemprod($itemprod->getCdtpitemprod());
                $newitemprod->setNmtpitemprod($itemprod->getNmtpitemprod());
                $newitemprod->setNrorginclusao($nrorg);
                $newitemprod->setCdoperultatu($cdoperador);
                $newitemprod->setNrorg($nrorg);
                $newitemprod->setDtinclusao($dataAtual);
                $newitemprod->setDtultatu($dataAtual);
                $newitemprod->setNrorgultatu($nrorg);
                $newitemprod->setCdoperinclusao($cdoperador);

                /*Um a um os itens são persistidos. O flush é executado na função de origem 'replicaItemProd'*/
                $newitemprod->persist();
            }

            Registry::getEntityManager()->flush();

        } catch (\Exception $e) {          
            throw $e;
        }

    }
}