<?php

/**
 * Namespace DiaFechaMes
 * @category PHP
 * @package Geral\Logic\FechamentoMes
 * @author  victornovy <victor.novy@teknisa.com>
 * @license http://erp.pebbian.com teknisa
 * @link    http://erp.pebbian.com
 */
namespace Geral\Logic\FechamentoMes;

use Geral\Entities\Diafecmes;
use Geral\Util\DateUtil;

/**
 * Class DiaFechaMes
 * @category PHP
 * @package Geral\Logic\FechamentoMes
 * @author  victornovy <victor.novy@teknisa.com>
 * @license http://erp.pebbian.com teknisa
 * @link    http://erp.pebbian.com
 */
class DiaFechaMes
{

    /**
     * Função chamada no decorrer da lógica.
     * Objetivo: Formatar a data de forma que possa ser inserida no banco e simplificação do código,
     * para evitar repetição.
     * @param String $data Data
     * @return \Setforms2\Shared\ORM\DateTime
     */
    public static function formataData($data)
    {
        if (strlen($data) == 19)
            $data = DateUtil::truncateString($data);
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }

    /**
     * Função chamada na Windows\WinPbi00189000\TabPbi00189001\Facade::insereDia
     * Objetivo: Inserir, Atualizar ou Deletar registros do banco de acordo com o que for
     * passado como parametro.
     * @param String $verifica    Verifica
     * @param String $dia         Dia
     * @param String $mes         Mes
     * @param String $ano         Ano
     * @param String $filial      Filial
     * @param String $organizacao Organização
     * @param String $data_atual  Data Inclusão e Alteração
     * @param String $operador    Operador Inclusão e Alteração
     * @return null
     */
    public static function configuracaoData($verifica, $dia, $mes, $ano, $filial, $organizacao, $data_atual, $operador)
    {
        /**
         * Salva, altera ou deleta no banco
         * @var $verifica Diafecmes
         */
        if ($dia != null) {
            $data = $dia."/".$mes."/".$ano;

            if (!$verifica) {

                $verifica = new Diafecmes();
                $verifica->setCdfilial($filial);
                $verifica->setDtfecmes(self::formataData($data));
                $verifica->setNrorg($organizacao);
                $verifica->setNrorginclusao($organizacao);
                $verifica->setNrorgultatu($organizacao);
                $verifica->setDtinclusao(self::formataData($data_atual));
                $verifica->setDtultatu(self::formataData($data_atual));
                $verifica->setCdoperinclusao($operador);
                $verifica->setCdoperultatu($operador);

            } else {
                $verifica->setDtfecmes(self::formataData($data));
                $verifica->setNrorgultatu($organizacao);
                $verifica->setDtultatu(self::formataData($data_atual));
                $verifica->setCdoperultatu($operador);
            }

            $verifica->persist();

        }else
            if($verifica)
                $verifica->delete();

        \Setforms2\Shared\Registry::getEntityManager()->flush();

    }
}